![CppLib](https://github.com/pthom/imgui_bundle/workflows/CppLib/badge.svg)
![Pip](https://github.com/pthom/imgui_bundle/workflows/Pip/badge.svg)
![Wheels](https://github.com/pthom/imgui_bundle/workflows/Wheels/badge.svg)


# ImGui Bundle
[ImGui Bundle](https://github.com/pthom/imgui_bundle) is a bundle for [Dear ImGui](https://github.com/ocornut/imgui.git), including various useful libraries from its ecosystem.
It enables to easily create ImGui applications in C++, as well as in Python.

The python bindings were autogenerated from the original C++ code, so that they are easier to keep up to date, and the python API closely matches the C++ api, making it possible to easily port research code from Python to C++.

<img src="https://traineq.org/imgui_bundle_doc/demo_bundle2.gif">

<table>
<tr>
    <td> <img src="https://traineq.org/imgui_bundle_doc/heart.gif"> </td>
    <td>  
      <b>Python</b><br>
      <img src="https://traineq.org/imgui_bundle_doc/heart_code2.png" width="350"><br>
      <b>C++</b><br>
      <img src="https://traineq.org/imgui_bundle_doc/heart_code_cpp2.png" width="350"><br>
    </td> 
</tr>
</table>


## Batteries included
ImGui Bundle includes:
* [imgui](https://github.com/ocornut/imgui.git) : Dear ImGui: Bloat-free Graphical User interface for C++ with minimal dependencies 
* [implot](https://github.com/epezent/implot): Immediate Mode Plotting
* [Hello ImGui](https://github.com/pthom/hello_imgui.git): cross-platform Gui apps with the simplicity of a "Hello World" app 
* [ImGuizmo](https://github.com/CedricGuillemet/ImGuizmo.git): Immediate mode 3D gizmo for scene editing and other controls based on Dear Imgui 
* [ImGuiColorTextEdit](https://github.com/BalazsJako/ImGuiColorTextEdit): Colorizing text editor for ImGui
* [imgui-node-editor](https://github.com/thedmd/imgui-node-editor): Node Editor built using Dear ImGui 
* [imgui-knobs](https://github.com/altschuler/imgui-knobs): Knobs widgets for ImGui
* [ImFileDialog](https://github.com/pthom/ImFileDialog.git): A file dialog library for Dear ImGui  
* [portable-file-dialogs](https://github.com/samhocevar/portable-file-dialogs)  Portable GUI dialogs library (C++11, single-header)
* [imgui_md](https://github.com/mekhontsev/imgui_md.git): Markdown renderer for Dear ImGui using MD4C parser
* [imspinner](https://github.com/dalerank/imspinner): Set of nice spinners for imgui 
* [imgui_toggle](https://github.com/cmdwtf/imgui_toggle): A toggle switch widget for Dear ImGui. [Homepage](https://cmd.wtf/projects#imgui-toggle)
* [ImmVision](https://github.com/pthom/immvision.git): immediate image debugger and insights 
* [imgui_tex_inspect](https://github.com/andyborrell/imgui_tex_inspect): A texture inspector tool for Dear ImGui 

## Philosophy
* Closely mirrors the original API of ImGui and other libraries
* Original code documentation is meticulously kept inside the python stubs. See for example the documentation for:
    * [imgui](https://github.com/pthom/imgui_bundle/blob/main/bindings/imgui_bundle/imgui/__init__.pyi)
    * [implot](https://github.com/pthom/imgui_bundle/blob/main/bindings/imgui_bundle/implot.pyi)
    * [hello imgui](https://github.com/pthom/imgui_bundle/blob/main/bindings/imgui_bundle/hello_imgui.pyi)
* Fully typed bindings, so that code completion works like a charm


## ImGui Backend

ImGui Bundle uses [Hello ImGui](https://github.com/pthom/hello_imgui), which is configured to use GLFW + OpenGL3.
Under C++, this is configurable (see Hello ImGui docs), with some adaptations inside on the [cmake side](cmake/add_hello_imgui.cmake).

# Usage with Python

## Install

````bash
# Install from pypi
pip install imgui-bundle

# or install from clone
git clone https://github.com/pthom/imgui_bundle.git
cd imgui_bundle
pip install -v .
````

## Demo

````bash
# imgui_bundle_demo will run the full demo shown on this page. 
# It also acts as a manual for ImGui Bundle with lots of examples and related code source.
imgui_bundle_demo 
````

The source for the demos can be found inside [bindings/imgui_bundle/demos_python](bindings/imgui_bundle/demos_python).

# Usage with C++

````
git clone https://github.com/pthom/imgui_bundle.git
````

Then, take inspiration from [demos_cpp/demo_haiku_implot_heart](bindings/imgui_bundle/demos_cpp/demo_haiku_implot_heart), 
or [demos_cpp/demo_widgets_docking](bindings/imgui_bundle/demos_cpp/demo_widgets_docking)
